import { select } from 'd3'

//We need this proxy becuse our resource service hasn't allows cross origin requests explicitly
//const proxyUrl = 'https://cors-proxy.htmldriven.com/?url=' 
const proxyUrl ='https://cors-anywhere.herokuapp.com/'
const overviewUrl = 'https://npropendata.rdw.nl/parkingdata/v2/'

const svg = select('svg')
const margin = {top: 48, right: 72, bottom: 120, left: 72}
const height = parseInt(svg.style('height'), 10) - margin.top - margin.bottom
const width = parseInt(svg.style('width'), 10) - margin.left - margin.right
/* Conventional margins: https://bl.ocks.org/mbostock/3019563. */
const group = svg
  .append('g')
  .attr('transform', 'translate(' + margin.left + ',' + margin.top + ')');

makeVisualization()

// Our main function which runs other functions to make a visualization
async function makeVisualization(){
  const allParkingFacilities = await getData(proxyUrl+overviewUrl)
  const preparedData = await prepareData(allParkingFacilities, 10)
  console.log(preparedData)
  //We should prob check if there can be more than one specification for each item
  console.log(preparedData.map(item=> item.specifications[0].capacity))
  const limitedAccessArr = preparedData.map(item=> item.limitedAccess)
  console.log(listUnique(limitedAccessArr))
  const specialDaysArr = preparedData.map(item=> item.limitedAccess)
  //Let's set up our scales in a separate function
	// setupScales()
	// setupAxes()
	// drawBars()
}

async function getData(url){
  let data = await d3.json(url)
  console.log("data", data)
  return data
}

// Returns all unique values in an array
function listUnique(dataArray){
  //logica which finds unique values
  let uniqueArray = []
  dataArray.forEach(item => {
    if (uniqueArray.indexOf(item) == -1)
    {
      uniqueArray.push(item)
    }
  })
  return uniqueArray
}

//If this functions starts getting really big, it might be useful to set up a separate module for it
//I'm not quite happy with the separation of concerns yet
async function prepareData(allParkingFacilities, amount = 10){
	//We need to do this annoying step because our data is wrapped in an object called ParkingFacilities
  allParkingFacilities = allParkingFacilities.ParkingFacilities
  console.log("allParkingFacilities:", allParkingFacilities)
  const selection = allParkingFacilities.slice(0, amount)
  console.log("selection", selection)
  const selectionIDs = selection.map(parkingLocation => parkingLocation.identifier)
  console.log("selectionIDs",selectionIDs)
  const baseURL = proxyUrl + overviewUrl + "static/"
  
  const promiseSomeFacilities = selectionIDs.map(id => getData(baseURL+id))
  
  console.log("promiseSomeFacilities", promiseSomeFacilities)
  const dataWrapped = await Promise.all(promiseSomeFacilities)
  console.log("dataWrapped", dataWrapped)
  const dataUnwrapped = dataWrapped.map(item => item.parkingFacilityInformation)
  return dataUnwrapped
}

//Draw the initial bars
function drawBars() {
}

//Set up the scales we'll use
function setupScales(){
}

//Attach x and y axes to our svg
function setupAxes(){
}
